@@ -77,7 +77,17 @@ class Call(DateModel):
 @run_in_background
 @parse_objects
 def save_call(call: Call):
-    call.save()
+    try:
+        call.save()
+    except Exception as error:
+        if "400 Cannot convert an array value in an array value." in str(error):
+            print("In save call, google error", error)
+            call.request.body = str(call.request.body)
+            call.response.body = str(call.response.body)
+            call.save()
+            return
+        else:
+            raise error
 
 
 async def get_request_body(request: FastAPIRequest):
@@ -173,10 +183,10 @@ async def make_request_obj_from_request(request: FastAPIRequest):
 
         cloudwatch_base_url = "https://console.aws.amazon.com/cloudwatch/home?region=us-east-1#logStream:group="
         request_obj.log_group_url = f"{cloudwatch_base_url}{request_obj.log_group_name}"
-        request_obj.stream_url = f"{request_obj.log_group_url};stream={request_obj.log_stream_name}".replace(
-            "[$LATEST]", "%5B$LATEST%5D"
-        ).replace(
-            "logStream", "logEventViewer"
+        request_obj.stream_url = (
+            f"{request_obj.log_group_url};stream={request_obj.log_stream_name}".replace(
+                "[$LATEST]", "%5B$LATEST%5D"
+            ).replace("logStream", "logEventViewer")
         )
 
     if "aws.event" in request.scope:
