@@ -1,8 +1,9 @@
-from magicdb.Models import MagicModel
+from magicdb.Models import FrontendParserModel
 from pydantic import EmailStr
+from firebase_admin import auth
 
 
-class CurrentUser(MagicModel):
+class CurrentUser(FrontendParserModel):
     uid: str
     phone_number: str = None
     email: EmailStr = None
@@ -15,3 +16,7 @@ class CurrentUser(MagicModel):
     user_id: str = None
     sub: str = None
     firebase: dict = {}
+    display_name: str = None
+
+    def update(self, **kwargs):
+        return auth.update_user(self.uid, **kwargs)
